aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2022-03-11 16:13:17 -0800
committerGerald Combs <gerald@wireshark.org>2022-03-12 00:19:13 +0000
commit87ff577257020190dbdcce0d3760f65e9407f304 (patch)
tree3a4152558b5aec34c5a833c44cd6a2966ab6a1b3
parent492a11a256f55239498f58cf6e46e453737c0c4a (diff)
Move Freedesktop files to resources/freedesktop.
-rw-r--r--CMakeLists.txt6
-rw-r--r--resources/freedesktop/org.wireshark.Wireshark-mime.xml (renamed from org.wireshark.Wireshark-mime.xml)0
-rw-r--r--resources/freedesktop/org.wireshark.Wireshark.desktop (renamed from org.wireshark.Wireshark.desktop)0
-rw-r--r--resources/freedesktop/org.wireshark.Wireshark.metainfo.xml (renamed from org.wireshark.Wireshark.metainfo.xml)6
-rwxr-xr-xtools/update-appdata.py10
-rw-r--r--wiretap/file_access.c2
6 files changed, 14 insertions, 10 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 2636e42882..fd63893e98 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -3467,15 +3467,15 @@ install(FILES ${SHARK_PUBLIC_HEADERS}
# Install icons and other desktop files for Freedesktop.org-compliant desktops.
if((BUILD_wireshark AND QT_FOUND) AND NOT (WIN32 OR APPLE))
- install(FILES org.wireshark.Wireshark-mime.xml
+ install(FILES resources/freedesktop/org.wireshark.Wireshark-mime.xml
DESTINATION "${CMAKE_INSTALL_DATAROOTDIR}/mime/packages"
RENAME org.wireshark.Wireshark.xml
)
- install(FILES org.wireshark.Wireshark.metainfo.xml
+ install(FILES resources/freedesktop/org.wireshark.Wireshark.metainfo.xml
DESTINATION "${CMAKE_INSTALL_DATAROOTDIR}/metainfo"
)
if(BUILD_wireshark AND QT_FOUND)
- install(FILES org.wireshark.Wireshark.desktop
+ install(FILES resources/freedesktop/org.wireshark.Wireshark.desktop
DESTINATION "${CMAKE_INSTALL_DATAROOTDIR}/applications")
endif()
foreach(size 16 24 32 48 64 128 256)
diff --git a/org.wireshark.Wireshark-mime.xml b/resources/freedesktop/org.wireshark.Wireshark-mime.xml
index a9f904c8f9..a9f904c8f9 100644
--- a/org.wireshark.Wireshark-mime.xml
+++ b/resources/freedesktop/org.wireshark.Wireshark-mime.xml
diff --git a/org.wireshark.Wireshark.desktop b/resources/freedesktop/org.wireshark.Wireshark.desktop
index a880a50a33..a880a50a33 100644
--- a/org.wireshark.Wireshark.desktop
+++ b/resources/freedesktop/org.wireshark.Wireshark.desktop
diff --git a/org.wireshark.Wireshark.metainfo.xml b/resources/freedesktop/org.wireshark.Wireshark.metainfo.xml
index 4b7d8ea47f..5bfc89a164 100644
--- a/org.wireshark.Wireshark.metainfo.xml
+++ b/resources/freedesktop/org.wireshark.Wireshark.metainfo.xml
@@ -1,5 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
-<!-- Copyright 2014 Richard Hughes <richard@hughsie.com> -->
+<!--
+ Copyright 2014 Richard Hughes <richard@hughsie.com>
+ The specification for this file can be found at
+ https://www.freedesktop.org/software/appstream/docs/chap-Metadata.html
+-->
<application>
<id type="desktop">org.wireshark.Wireshark</id>
diff --git a/wiretap/file_access.c b/wiretap/file_access.c
index 2f6d6bf287..adf98b88cd 100644
--- a/wiretap/file_access.c
+++ b/wiretap/file_access.c
@@ -353,7 +353,7 @@ wtap_get_all_capture_file_extensions_list(void)
* NOTE: when adding file formats to this list you may also want to add them
* to the following files so that the various desktop environments will
* know that Wireshark can open the file:
- * 1) org.wireshark.Wireshark-mime.xml (for freedesktop.org environments)
+ * 1) resources/freedesktop/org.wireshark.Wireshark-mime.xml (for freedesktop.org environments)
* 2) packaging/macosx/Info.plist.in (for macOS)
* 3) packaging/nsis/AdditionalTasksPage.ini, packaging/nsis/common.nsh,
* and packaging/wix/ComponentGroups.wxi (for Windows)
diff --git a/tools/update-appdata.py b/tools/update-appdata.py
index cdb2d5fc81..c2f8d57a29 100755
--- a/tools/update-appdata.py
+++ b/tools/update-appdata.py
@@ -1,16 +1,16 @@
#!/usr/bin/env python3
#
# update-appdata.py - Update the <releases/> section of org.wireshark.Wireshark.metainfo.xml.
#
# Wireshark - Network traffic analyzer
# By Gerald Combs <gerald@wireshark.org>
# Copyright 1998 Gerald Combs
#
# SPDX-License-Identifier: GPL-2.0-or-later
-'''Update the <release> tag in org.wireshark.Wireshark.metainfo.xml
+'''Update the <release> tag in resources/freedesktop/org.wireshark.Wireshark.metainfo.xml
According to https://www.freedesktop.org/software/appstream/docs/chap-Metadata.html
-the <releases/> tag in org.wireshark.Wireshark.metainfo.xml should contain release
+the <releases/> tag in resources/freedesktop/org.wireshark.Wireshark.metainfo.xml should contain release
information sorted newest to oldest.
As part of our release process, when we create release tag x.y.z, we tag
@@ -22,7 +22,7 @@ v3.0.1 2019-04-08 release tag
v3.0.2rc0 2019-04-08 next commit after v3.0.1
Find a list of release versions based on our most recent rc0 tag and
-update the <releases/> section of org.wireshark.Wireshark.metainfo.xml accordingly.
+update the <releases/> section of resources/freedesktop/org.wireshark.Wireshark.metainfo.xml accordingly.
Assume that the tag for the most recent release doesn't exist and use
today's date for it.
'''
@@ -41,7 +41,7 @@ def main():
sys.exit(2)
this_dir = os.path.dirname(__file__)
- appdata_xml = os.path.join(this_dir, '..', 'org.wireshark.Wireshark.metainfo.xml')
+ appdata_xml = os.path.join(this_dir, '..', 'resources', 'freedesktop', 'org.wireshark.Wireshark.metainfo.xml')
try:
tag_cp = subprocess.run(
@@ -1,16 +1,16 @@
#!/usr/bin/env python3
#
-# update-appdata.py - Update the <releases/> section of org.wireshark.Wireshark.metainfo.xml.
+# update-appdata.py - Update the <releases/> section of resources/freedesktop/org.wireshark.Wireshark.metainfo.xml.
#
# Wireshark - Network traffic analyzer